Container class
A simple Dependency Injection Container.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createScope(
) → Container - Creates a new scope (child container) that inherits descriptors.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register<
T> (Object instance) → void - Register a dependency instance as a Singleton.
-
registerFactory<
T> (T factory(Container), {ServiceLifetime lifetime = ServiceLifetime.transient}) → void - Register a dynamic factory for a service.
-
resolve<
T> () → T - Resolve a dependency
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited