ServiceDescriptor<T> class
A descriptor for a registered service.
Constructors
- ServiceDescriptor(ServiceLifetime lifetime, T factory(Container))
Properties
- factory → T Function(Container)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lifetime → ServiceLifetime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited